@@ -2,7 +2,7 @@ AICc <- function(object)
 {
   aic <- AIC(object)
   if (!is.numeric(aic)) stop("Cannot calculate AIC!")
-  k <- length(coef(object)) + 1
+  k <- length(coef(object))
   n <- length(residuals(object))
  	aic + ((2 * k * (k + 1))/(n - k - 1))
 } 
\ No newline at end of file
