@@ -1,16 +1,12 @@
 Cy0 <- function(object, plot = FALSE, add = FALSE, ...)
 {
-  EFFobj<- eff(object)
-  SEQ <- EFFobj$eff.x      
-  D1seq <- object$MODEL$d1(SEQ, coef(object))
-  maxD1 <- which.max(D1seq)
-  cpD1 <- SEQ[maxD1] 
-  Fluo <- as.numeric(pcrpred(object, newdata = data.frame(Cycles = cpD1), which = "y"))         
+  cpD1 <- efficiency(object, plot = FALSE)$cpD1 
+  Fluo <- as.numeric(predict(object, newdata = data.frame(Cycles = cpD1), which = "y")) 
   slope <- object$MODEL$d1(cpD1, t(coef(object)))
   Cy0 <- cpD1 - (Fluo/slope)
   
   if (plot) {
-    pcrplot(object, ...) 
+    plot(object, ...) 
     add = TRUE
   }
   if (add) {
