@@ -9,6 +9,9 @@ conf = 0.95,
 B = 200
 )
 {
+  oldpar <- par(no.readonly = TRUE) 
+  on.exit(par(oldpar)) 
+  
   if (class(refcurve)[1] != "modlist") stop("'refcurve' is not a 'modlist'!")
   if (!is.null(predcurve) & class(predcurve)[1] != "modlist") stop("'predcurve' is not a 'modlist'!")
   if (thresh != "cpD2" && !is.numeric(thresh)) stop("'thresh' must be either 'cpD2' or numeric!")
