@@ -7,6 +7,9 @@ shift = 0,
 amount = NULL,
 ...) 
 {  
+    oldpar <- par(no.readonly = TRUE) 
+    on.exit(par(oldpar)) 
+  
     if (!is.numeric(type)) type <- match.arg(type, c("cpD2", "cpD1", "maxE", "expR", "Cy0", "CQ", "maxRatio"))
     if (!is.null(amount) && !is.numeric(amount))
         stop("'amount' must be numeric!")
