@@ -5,6 +5,9 @@ smooth = TRUE,
 plot = TRUE,
 ...)
 {
+  oldpar <- par(no.readonly = TRUE) 
+  on.exit(par(oldpar)) 
+  
   method <- match.arg(method)
   if (class(x)[1] == "pcrfit") ml <- modlist(x) else ml <- x    
   COLS <- rainbow(length(ml))   
