@@ -16,7 +16,9 @@ plot.Area = TRUE,
 cut.Area = 0,
 ...)
 {
-  options(warn = -1)
+  oldpar <- par(no.readonly = TRUE) 
+  on.exit(par(oldpar))
+  
   if (is.null(temps)) temps <- seq(from = 1, to = ncol(data), by = 2) 
   if (is.null(fluos)) fluos <- seq(from = 2, to = ncol(data), by = 2)
   if (length(temps) != length(fluos)) stop("Numbers of temperature columns and fluorescence columns do not match!")
