@@ -9,6 +9,9 @@ conf = 0.95,
 verbose = TRUE,
 ...)
 {
+  oldpar <- par(no.readonly = TRUE) 
+  on.exit(par(oldpar))
+  
   type <- match.arg(type)
   
   if (class(object)[1] != "pcrfit") stop("Use only with objects of class 'pcrfit'!")   
