@@ -8,11 +8,12 @@ par2D = list(),
 par3D = list(),
 ...) 
 {
+  oldpar <- par(no.readonly = TRUE) 
+  on.exit(par(oldpar))
+  
   type <- match.arg(type)    
   object <- x
   
-  print(class(x))
-  
   if (class(x)[1] != "modlist") modLIST <- list(object) else modLIST <- object      
     
   ## extract cycles and fluorescence values from all curves
