@@ -18,6 +18,9 @@ verbose = FALSE,
 ...
 )
 {            
+  oldpar <- par(no.readonly = TRUE) 
+  on.exit(par(oldpar))
+  
   ## check for correct inputs  
   type <- match.arg(type)
   dist.sim = match.arg(dist.sim)
