@@ -11,9 +11,10 @@ dataout = NULL,
 verbose = TRUE,
 ...)
 {
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar)) 
+  
   if (class(data)[2] != "pcrbatch") stop("data is not of class 'pcrbatch'!")
-  options(warn = -1)
-
   combs <- match.arg(combs)
   
   ## substitute .1 etc from import 
