@@ -1,5 +1,8 @@
 resplot <- function(object, overlay = TRUE, ylim = NULL, ...)
 {
+  oldpar <- par(no.readonly = TRUE) 
+  on.exit(par(oldpar)) 
+  
   ## extract residuals
   RESID <- try(as.numeric(residuals(object)), silent = TRUE)
   if (inherits(RESID, "try-error")) stop("'object' does not have any residuals!")
