@@ -323,7 +323,7 @@ data.frame.na <- function (..., row.names = NULL, check.rows = FALSE, check.name
                 xi1 <- xi[[j]]
                 if (is.vector(xi1) || is.factor(xi1))
                   xi[[j]] <- c(xi1, rep(NA, nr - nrows[i]))
-                else if (is.character(xi1) && class(xi1) == "AsIs")
+                else if (is.character(xi1) && inherits(xi1, "AsIs"))
                   xi[[j]] <- structure(c(xi1, rep(NA, nr - nrows[i])),
                     class = class(xi1))
                 else if (inherits(xi1, "Date") || inherits(xi1,
@@ -424,7 +424,9 @@ cmean <- function(x, E) -log(mean(E^-x, na.rm = TRUE))/log(E)
 xyy.plot <- function(x, y1, y2, y1.par = NULL, y2.par = NULL, 
                      first = NULL, y1.last = NULL, y2.last = NULL, ...)
 {
-  options(warn = -1)
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar)) 
+  
   if (is.null(y1.par)) y1.par <- list()
   if (is.null(y2.par)) y2.par <- list()   
   par(mar = c(5, 4, 4, 5))   
@@ -838,32 +840,6 @@ peaks <- function (series, span = 3, what = c("max", "min"), do.pad = TRUE, ...)
     val
 }
 
-#################################################################
-###### get data from environments for fitting ###################
-fetchData <- function(object)
-{
-  ### 'pcrfit' object
-  if (class(object)[1] == "pcrfit") DATA <- object$DATA
-  
-  ### any other object
-  if (class(object$call$data) == "name") DATA <- eval(object$call$data)
-  else if (class(object$call$data) == "data.frame"  || class(object$call$data) == "matrix") DATA <- object$call$data
-  else if (is.null(object$call$data)) DATA <- as.data.frame(sapply(all.vars(object$call$formula), function(a) get(a, envir = .GlobalEnv)))
-  
-  ### get variables from formula
-  VARS <- all.vars(object$call$formula)
-  LHS <- VARS[1]
-  RHS <- VARS[-1]
-  
-  ### get predictor and response positions
-  PRED.pos <- match(RHS, colnames(DATA))  
-  PRED.name <- RHS[which(!is.na(PRED.pos))]
-  PRED.pos <- as.numeric(na.omit(PRED.pos))
-  RESP.pos <- match(LHS, colnames(DATA))  
-            
-  return(list(data = DATA, pred.pos = PRED.pos, resp.pos = RESP.pos, pred.name = PRED.name))
-}
-
 #############################################################################
 ## create n-sequence (equidistant) with selected mean and s.d.  => refmean ##
 makeStat <- function(n, MEAN, SD) 
@@ -1097,3 +1073,31 @@ baseline <- function(cyc = NULL, fluo = NULL, model = NULL,
   if (baseline != "parm") return(fluo - BASE) else return(newMODEL)
 }
 
+#################################################################
+###### get data from environments for fitting ###################
+fetchData <- function(object)
+{
+  ### 'pcrfit' object
+  if (as.character(class(object)[1]) == "pcrfit") DATA <- object$DATA
+  
+  ### any other object
+  if (as.character(class(object$call$data)) == "name") DATA <- eval(object$call$data)
+  else if (as.character(class(object$call$data)) == "data.frame"  || as.character(class(object$call$data)) == "matrix") DATA <- object$call$data
+  else if (is.null(object$call$data)) DATA <- as.data.frame(sapply(all.vars(object$call$formula), function(a) get(a, envir = .GlobalEnv)))
+  
+  ### get variables from formula
+  VARS <- all.vars(object$call$formula)
+  LHS <- VARS[1]
+  RHS <- VARS[-1]
+  
+  ### get predictor and response positions
+  PRED.pos <- match(RHS, colnames(DATA))  
+  PRED.name <- RHS[which(!is.na(PRED.pos))]
+  PRED.pos <- as.numeric(na.omit(PRED.pos))
+  RESP.pos <- match(LHS, colnames(DATA))  
+  
+  return(list(data = DATA, pred.pos = PRED.pos, resp.pos = RESP.pos, pred.name = PRED.name))
+}
+
+
+
